Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
- type CertificateExpansion
- type CertificateInterface
- type CertificatesGetter
- type CertmanagerV1alpha1Client
- func (c *CertmanagerV1alpha1Client) Certificates(namespace string) CertificateInterface
- func (c *CertmanagerV1alpha1Client) Challenges(namespace string) ChallengeInterface
- func (c *CertmanagerV1alpha1Client) ClusterIssuers() ClusterIssuerInterface
- func (c *CertmanagerV1alpha1Client) Issuers(namespace string) IssuerInterface
- func (c *CertmanagerV1alpha1Client) Orders(namespace string) OrderInterface
- func (c *CertmanagerV1alpha1Client) RESTClient() rest.Interface
- type CertmanagerV1alpha1Interface
- type ChallengeExpansion
- type ChallengeInterface
- type ChallengesGetter
- type ClusterIssuerExpansion
- type ClusterIssuerInterface
- type ClusterIssuersGetter
- type IssuerExpansion
- type IssuerInterface
- type IssuersGetter
- type OrderExpansion
- type OrderInterface
- type OrdersGetter
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CertificateExpansion ¶
type CertificateExpansion interface{}
type CertificateInterface ¶
type CertificateInterface interface {
Create(*v1alpha1.Certificate) (*v1alpha1.Certificate, error)
Update(*v1alpha1.Certificate) (*v1alpha1.Certificate, error)
UpdateStatus(*v1alpha1.Certificate) (*v1alpha1.Certificate, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1alpha1.Certificate, error)
List(opts v1.ListOptions) (*v1alpha1.CertificateList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.Certificate, err error)
CertificateExpansion
}
CertificateInterface has methods to work with Certificate resources.
type CertificatesGetter ¶
type CertificatesGetter interface {
Certificates(namespace string) CertificateInterface
}
CertificatesGetter has a method to return a CertificateInterface. A group's client should implement this interface.
type CertmanagerV1alpha1Client ¶
type CertmanagerV1alpha1Client struct {
// contains filtered or unexported fields
}
CertmanagerV1alpha1Client is used to interact with features provided by the certmanager.k8s.io group.
func New ¶
func New(c rest.Interface) *CertmanagerV1alpha1Client
New creates a new CertmanagerV1alpha1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*CertmanagerV1alpha1Client, error)
NewForConfig creates a new CertmanagerV1alpha1Client for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *CertmanagerV1alpha1Client
NewForConfigOrDie creates a new CertmanagerV1alpha1Client for the given config and panics if there is an error in the config.
func (*CertmanagerV1alpha1Client) Certificates ¶
func (c *CertmanagerV1alpha1Client) Certificates(namespace string) CertificateInterface
func (*CertmanagerV1alpha1Client) Challenges ¶
func (c *CertmanagerV1alpha1Client) Challenges(namespace string) ChallengeInterface
func (*CertmanagerV1alpha1Client) ClusterIssuers ¶
func (c *CertmanagerV1alpha1Client) ClusterIssuers() ClusterIssuerInterface
func (*CertmanagerV1alpha1Client) Issuers ¶
func (c *CertmanagerV1alpha1Client) Issuers(namespace string) IssuerInterface
func (*CertmanagerV1alpha1Client) Orders ¶
func (c *CertmanagerV1alpha1Client) Orders(namespace string) OrderInterface
func (*CertmanagerV1alpha1Client) RESTClient ¶
func (c *CertmanagerV1alpha1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
type CertmanagerV1alpha1Interface ¶
type CertmanagerV1alpha1Interface interface {
RESTClient() rest.Interface
CertificatesGetter
ChallengesGetter
ClusterIssuersGetter
IssuersGetter
OrdersGetter
}
type ChallengeExpansion ¶
type ChallengeExpansion interface{}
type ChallengeInterface ¶
type ChallengeInterface interface {
Create(*v1alpha1.Challenge) (*v1alpha1.Challenge, error)
Update(*v1alpha1.Challenge) (*v1alpha1.Challenge, error)
UpdateStatus(*v1alpha1.Challenge) (*v1alpha1.Challenge, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1alpha1.Challenge, error)
List(opts v1.ListOptions) (*v1alpha1.ChallengeList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.Challenge, err error)
ChallengeExpansion
}
ChallengeInterface has methods to work with Challenge resources.
type ChallengesGetter ¶
type ChallengesGetter interface {
Challenges(namespace string) ChallengeInterface
}
ChallengesGetter has a method to return a ChallengeInterface. A group's client should implement this interface.
type ClusterIssuerExpansion ¶
type ClusterIssuerExpansion interface{}
type ClusterIssuerInterface ¶
type ClusterIssuerInterface interface {
Create(*v1alpha1.ClusterIssuer) (*v1alpha1.ClusterIssuer, error)
Update(*v1alpha1.ClusterIssuer) (*v1alpha1.ClusterIssuer, error)
UpdateStatus(*v1alpha1.ClusterIssuer) (*v1alpha1.ClusterIssuer, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1alpha1.ClusterIssuer, error)
List(opts v1.ListOptions) (*v1alpha1.ClusterIssuerList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.ClusterIssuer, err error)
ClusterIssuerExpansion
}
ClusterIssuerInterface has methods to work with ClusterIssuer resources.
type ClusterIssuersGetter ¶
type ClusterIssuersGetter interface {
ClusterIssuers() ClusterIssuerInterface
}
ClusterIssuersGetter has a method to return a ClusterIssuerInterface. A group's client should implement this interface.
type IssuerExpansion ¶
type IssuerExpansion interface{}
type IssuerInterface ¶
type IssuerInterface interface {
Create(*v1alpha1.Issuer) (*v1alpha1.Issuer, error)
Update(*v1alpha1.Issuer) (*v1alpha1.Issuer, error)
UpdateStatus(*v1alpha1.Issuer) (*v1alpha1.Issuer, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1alpha1.Issuer, error)
List(opts v1.ListOptions) (*v1alpha1.IssuerList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.Issuer, err error)
IssuerExpansion
}
IssuerInterface has methods to work with Issuer resources.
type IssuersGetter ¶
type IssuersGetter interface {
Issuers(namespace string) IssuerInterface
}
IssuersGetter has a method to return a IssuerInterface. A group's client should implement this interface.
type OrderExpansion ¶
type OrderExpansion interface{}
type OrderInterface ¶
type OrderInterface interface {
Create(*v1alpha1.Order) (*v1alpha1.Order, error)
Update(*v1alpha1.Order) (*v1alpha1.Order, error)
UpdateStatus(*v1alpha1.Order) (*v1alpha1.Order, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1alpha1.Order, error)
List(opts v1.ListOptions) (*v1alpha1.OrderList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.Order, err error)
OrderExpansion
}
OrderInterface has methods to work with Order resources.
type OrdersGetter ¶
type OrdersGetter interface {
Orders(namespace string) OrderInterface
}
OrdersGetter has a method to return a OrderInterface. A group's client should implement this interface.